/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://jersey.dev.java.net/CDDL+GPL.html
 * or jersey/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at jersey/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.jersey.qe.util;

import java.net.URI;
import java.util.Hashtable;

/**
 *
 * @author Naresh (Srinivas.Bhimisetty@Sun.Com)
 */
public class JerseyAppContainer implements UtilConstants {

    /**
     * Reference to container type on which deployments are to be done.
     */
    private String containerType;

    /**
     * Base URI for the resources.
     */
    private URI baseUri;

    /**
     * Map of container types to container handles.
     */
    private Hashtable<String,Class> containerTable;

    /**
     * Handle to container.
     */
    private RunnableContainer container;

    /**
     * Constructor.
     * @param containerType
     * @param baseUri
     */
    public JerseyAppContainer(String containerType, URI baseUri) {

        containerTable = new Hashtable<String, Class>();
        containerTable.put(EMBEDDED_GF_V3, EmbeddedGlassfish.class);
        containerTable.put(GRIZZLY_WEB_CONTAINER, GrizzlyContainer.class);
        containerTable.put(HTTP_SERVER, HTTPContainer.class);
        if( !containerTable.containsKey(containerType) ) {
            System.out.println("Invalid container.type attribute passed. Expected one of :: ");
            System.out.println("====================");
            System.out.println(EMBEDDED_GF_V3 + "\n" + GRIZZLY_WEB_CONTAINER +
                    "\n" + HTTP_SERVER + "\n" + GF_V2 + "\n" + GF_V3);
            System.out.println("====================");
            System.exit(-1);
        }
        this.containerType = containerType;
        this.baseUri = baseUri;
    }

    /**
     * Deploy the resource(s) to the container and start it.
     * @throws java.lang.Exception
     */
    public void startServer() throws Exception {
        container = (RunnableContainer) (containerTable.get(containerType).newInstance());
        container.setBaseUri(baseUri);
        container.start();
    }

    /**
     * Stop the container.
     * @throws java.lang.Exception
     */
    public void stopServer() throws Exception {
        container.stop();
    }

}